package com.fs.his.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.fs.his.domain.FsPhysicalReportTemplateField;
import org.apache.ibatis.annotations.Param;

/**
 * 体检报告模板字段Mapper接口
 *
 * @author fs
 * @date 2025-07-24
 */
public interface FsPhysicalReportTemplateFieldMapper extends BaseMapper<FsPhysicalReportTemplateField> {
    /**
     * 查询体检报告模板字段
     *
     * @param id 体检报告模板字段主键
     * @return 体检报告模板字段
     */
    FsPhysicalReportTemplateField selectFsPhysicalReportTemplateFieldById(String id);

    /**
     * 查询体检报告模板字段列表
     *
     * @param fsPhysicalReportTemplateField 体检报告模板字段
     * @return 体检报告模板字段集合
     */
    List<FsPhysicalReportTemplateField> selectFsPhysicalReportTemplateFieldList(FsPhysicalReportTemplateField fsPhysicalReportTemplateField);

    /**
     * 新增体检报告模板字段
     *
     * @param fsPhysicalReportTemplateField 体检报告模板字段
     * @return 结果
     */
    int insertFsPhysicalReportTemplateField(FsPhysicalReportTemplateField fsPhysicalReportTemplateField);

    /**
     * 修改体检报告模板字段
     *
     * @param fsPhysicalReportTemplateField 体检报告模板字段
     * @return 结果
     */
    int updateFsPhysicalReportTemplateField(FsPhysicalReportTemplateField fsPhysicalReportTemplateField);

    /**
     * 删除体检报告模板字段
     *
     * @param id 体检报告模板字段主键
     * @return 结果
     */
    int deleteFsPhysicalReportTemplateFieldById(String id);

    /**
     * 批量删除体检报告模板字段
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteFsPhysicalReportTemplateFieldByIds(String[] ids);

    /**
     * 批量插入模板自定义字段
     *
     * @param templateFieldList 插入数据
     **/
    void batchInsertFsPhysicalReportTemplateField(@Param("templateFieldList") List<FsPhysicalReportTemplateField> templateFieldList);

    /**
     * 删除自定也模板
     * **/
    void deleteTemplateFieldByTemplateId(@Param("templateId") Long templateId);
}
